Module minimum

minimum test for mpir

Functions

calc_binomial_coefficient_test
calc binomial coefficient
calc_fact_test
calc fact test
calc_fib_test
calc fib test
calc_fit_test
calc fit test expected on the single thread for mpf_set_default_prec
calc_gcd_test
calc gcd test
calc_lcm_test
calc lcm test
calc_logical_test
calc logical test
calc_mod_prime_test
calc mod prime test
calc_mpf_prec64_test
calc mpf prec64 test expected on the single thread for mpf_set_default_prec
calc_mpq_test
calc mpq test
calc_mpz_test
calc mpz test
calc_napier_test
calc napier test expected on the single thread for mpf_set_default_prec
calc_pi_euler_test
calc pi euler test CAUTION too slow digits >= 9 expected on the single thread for mpf_set_default_prec
calc_pi_gauss_legendre_test
calc pi gauss legendre test expected on the single thread for mpf_set_default_prec
calc_rand_test
calc rand test expected on the single thread for mpf_set_default_prec
compare_test
compare test expected on the single thread for mpf_set_default_prec
ept_test
ept test
fo
fo pub fn fo<W: Write>(w: &mut BufWriter<W>, o: String)
load_digits
load_digits
ops_test
ops test expected on the single thread for mpf_set_default_prec
significant_digits_test
significant digits test expected on the single thread for mpf_set_default_prec
trim_padding_digits
trim_padding_digits (trim only Ns from 0.NN…NNe+1) padding 0 when last digits 0 will be cut (0.NNNNe+1 to 0.NNNN0…0e+1)