minimum test for mpir
Functions
- calc_
binomial_ coefficient_ test - calc binomial coefficient
- calc_
fact_ test - calc fact test
- calc_
fib_ test - calc fib test
- calc_
fit_ test - calc fit test expected on the single thread for mpf_set_default_prec
- calc_
gcd_ test - calc gcd test
- calc_
lcm_ test - calc lcm test
- calc_
logical_ test - calc logical test
- calc_
mod_ prime_ test - calc mod prime test
- calc_
mpf_ prec64_ test - calc mpf prec64 test expected on the single thread for mpf_set_default_prec
- calc_
mpq_ test - calc mpq test
- calc_
mpz_ test - calc mpz test
- calc_
napier_ test - calc napier test expected on the single thread for mpf_set_default_prec
- calc_
pi_ euler_ test - calc pi euler test CAUTION too slow digits >= 9 expected on the single thread for mpf_set_default_prec
- calc_
pi_ gauss_ legendre_ test - calc pi gauss legendre test expected on the single thread for mpf_set_default_prec
- calc_
rand_ test - calc rand test expected on the single thread for mpf_set_default_prec
- compare_
test - compare test expected on the single thread for mpf_set_default_prec
- ept_
test - ept test
- fo
- fo pub fn fo<W: Write>(w: &mut BufWriter<W>, o: String)
- load_
digits - load_digits
- ops_
test - ops test expected on the single thread for mpf_set_default_prec
- significant_
digits_ test - significant digits test expected on the single thread for mpf_set_default_prec
- trim_
padding_ digits - trim_padding_digits (trim only Ns from 0.NN…NNe+1) padding 0 when last digits 0 will be cut (0.NNNNe+1 to 0.NNNN0…0e+1)